==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/LocalDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BaseDataSourceDescriptionMetadata } from "./BaseDataSourceDescriptionMetadata";
import { LocalDataSourceDescription } from "./LocalDataSourceDescription";
/**
 * @hidden
 */
var LocalDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LocalDataSourceDescriptionMetadata, _super);
    function LocalDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LocalDataSourceDescriptionMetadata.b = function (a) {
        if (LocalDataSourceDescriptionMetadata.a == null) {
            LocalDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LocalDataSourceDescriptionMetadata.c(LocalDataSourceDescriptionMetadata.a);
        }
        if (a.g(LocalDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.s(LocalDataSourceDescriptionMetadata.a);
    };
    LocalDataSourceDescriptionMetadata.c = function (a) {
        BaseDataSourceDescriptionMetadata.c(a);
        a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,j:dataSource,wf:ItemsSource)DataRef::object");
    };
    LocalDataSourceDescriptionMetadata.d = function (a) {
        LocalDataSourceDescriptionMetadata.b(a);
        a.u("LocalDataSource", function () { return new LocalDataSourceDescription(); });
        a.t("LocalDataSource", LocalDataSourceDescriptionMetadata.a);
    };
    LocalDataSourceDescriptionMetadata.$t = markType(LocalDataSourceDescriptionMetadata, 'LocalDataSourceDescriptionMetadata');
    LocalDataSourceDescriptionMetadata.a = null;
    return LocalDataSourceDescriptionMetadata;
}(Base));
export { LocalDataSourceDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LocalDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BaseDataSourceDescriptionMetadata } from "./BaseDataSourceDescriptionMetadata";
import { LocalDataSourceDescription } from "./LocalDataSourceDescription";
/**
 * @hidden
 */
var LocalDataSourceDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LocalDataSourceDescriptionMetadata, _super);
    function LocalDataSourceDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LocalDataSourceDescriptionMetadata.b = function (a) {
        if (LocalDataSourceDescriptionMetadata.a == null) {
            LocalDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LocalDataSourceDescriptionMetadata.c(LocalDataSourceDescriptionMetadata.a);
        }
        if (a.j(LocalDataSourceDescriptionMetadata.a)) {
            return;
        }
        a.y(LocalDataSourceDescriptionMetadata.a);
    };
    LocalDataSourceDescriptionMetadata.c = function (a) {
        BaseDataSourceDescriptionMetadata.c(a);
        a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,j:dataSource,wf:ItemsSource)DataRef::object");
    };
    LocalDataSourceDescriptionMetadata.d = function (a) {
        LocalDataSourceDescriptionMetadata.b(a);
        a.aa("LocalDataSource", function () { return new LocalDataSourceDescription(); });
        a.z("LocalDataSource", LocalDataSourceDescriptionMetadata.a);
    };
    LocalDataSourceDescriptionMetadata.$t = markType(LocalDataSourceDescriptionMetadata, 'LocalDataSourceDescriptionMetadata');
    LocalDataSourceDescriptionMetadata.a = null;
    return LocalDataSourceDescriptionMetadata;
}(Base));
export { LocalDataSourceDescriptionMetadata };
